@@ -7,6 +7,8 @@ import (
 )
 
 func Test_NormalizeOrgRepoURL(t *testing.T) {
+	t.Parallel()
+
 	tests := map[string]struct {
 		Provider provider
 		Repo     string
@@ -43,6 +45,8 @@ func Test_NormalizeOrgRepoURL(t *testing.T) {
 }
 
 func Test_NormalizeBitbucketRepo(t *testing.T) {
+	t.Parallel()
+
 	tests := map[string]struct {
 		Repo string
 		Out  string
@@ -69,6 +73,8 @@ func Test_NormalizeBitbucketRepo(t *testing.T) {
 }
 
 func Test_NormalizeGitlabRepo(t *testing.T) {
+	t.Parallel()
+
 	tests := map[string]struct {
 		Repo string
 		Out  string
@@ -93,3 +99,73 @@ func Test_NormalizeGitlabRepo(t *testing.T) {
 		}
 	}
 }
+
+func TestGenerateLink(t *testing.T) {
+	t.Parallel()
+
+	type args struct {
+		repo   string
+		commit string
+		file   string
+		line   int64
+	}
+	tests := []struct {
+		name string
+		args args
+		want string
+	}{
+		{
+			name: "github link gen",
+			args: args{
+				repo:   "https://github.com/trufflesec-julian/confluence-go-api.git",
+				commit: "047b4a2ba42fc5b6c0bd535c5307434a666db5ec",
+				file:   ".gitignore",
+			},
+			want: "https://github.com/trufflesec-julian/confluence-go-api/blob/047b4a2ba42fc5b6c0bd535c5307434a666db5ec/.gitignore",
+		},
+		{
+			name: "github link gen with line",
+			args: args{
+				repo:   "https://github.com/trufflesec-julian/confluence-go-api.git",
+				commit: "047b4a2ba42fc5b6c0bd535c5307434a666db5ec",
+				file:   ".gitignore",
+				line:   int64(4),
+			},
+			want: "https://github.com/trufflesec-julian/confluence-go-api/blob/047b4a2ba42fc5b6c0bd535c5307434a666db5ec/.gitignore#L4",
+		},
+		{
+			name: "github link gen - no file",
+			args: args{
+				repo:   "https://github.com/trufflesec-julian/confluence-go-api.git",
+				commit: "047b4a2ba42fc5b6c0bd535c5307434a666db5ec",
+			},
+			want: "https://github.com/trufflesec-julian/confluence-go-api/commit/047b4a2ba42fc5b6c0bd535c5307434a666db5ec",
+		},
+		{
+			name: "Azure link gen",
+			args: args{
+				repo:   "https://dev.azure.com/org/project/_git/repo",
+				commit: "abcdef",
+				file:   "main.go",
+			},
+			want: "https://dev.azure.com/org/project/_git/repo?path=main.go&version=GBabcdef",
+		},
+		{
+			name: "Azure link gen with line",
+			args: args{
+				repo:   "https://dev.azure.com/org/project/_git/repo",
+				commit: "abcdef",
+				file:   "main.go",
+				line:   int64(20),
+			},
+			want: "https://dev.azure.com/org/project/_git/repo?path=main.go&version=GBabcdef&line=20",
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			if got := GenerateLink(tt.args.repo, tt.args.commit, tt.args.file, tt.args.line); got != tt.want {
+				t.Errorf("generateLink() = %v, want %v", got, tt.want)
+			}
+		})
+	}
+}
